"""
    This package owns personnal and useful machine learning
    functions.

    Use :

    >>> from mj_package import proclamer
    >>> proclamer()
"""
# VERSION
__version__ = "0.0.1"

from mj_package.core import proclamer,add,sub




from setuptools import setup, find_packages


import mj_package

setup(
    name = 'mj_package',
    version=mj_package.__version__,
    author = 'Marc Juillard',
    author_email = "dont_ask@gmail.com",
    description = "Personal ml packages",
    long_description = open('README.md').read(),
    # internal package and exclusions
    packages = find_packages(
        exclude=[
            "*tests",
            "*.tests.*",
            "test",
            "log",
            "log.*",
            "*.log",
            "*.log.*"
        ]
    ),
    # package to install
    #install_requires=["pandas==1.0.0"],
    # include MANIFEST.in
    include_package_data = True,
    url='http://gitXXXX',
    # desciption for the boots that're going to classify the lib
    Classifiers =[
        "licence :: WTFPL"],
    # command shell
    entry_points ={
        'console_scripts' : [
            'proclamer= mj_package.core:proclamer',
        ],
    },
    )


"""
    This package owns personnal and useful machine learning
    functions.

    Use :

    >>> from mj_package import proclamer
    >>> proclamer()
"""

# WHAT YOU CAN IMPORT
__all__=['proclamer','add','sub']

# CODE
from datetime import datetime

def proclamer()-> None:
    """
        Just an example....
    """
    text =  "We are the [%s] " % datetime.now()
    print(text)

def add(a:float,b:float)->float:
    """
        Addition...
    """
    return(a+b)

def sub(a:float,b:float)->float:
    """
        Addition...
    """
    return(a-b)

def nothing():
    print("hello_word")

if __name__=="__main__":
    main()

